#[non_exhaustive]pub struct CreatePrivateConnectivityConfigInputBuilder { /* private fields */ }Expand description
A builder for CreatePrivateConnectivityConfigInput.
Implementations
Sourceimpl CreatePrivateConnectivityConfigInputBuilder
impl CreatePrivateConnectivityConfigInputBuilder
Sourcepub fn outpost_id(self, input: impl Into<String>) -> Self
pub fn outpost_id(self, input: impl Into<String>) -> Self
The ID or ARN of the Outpost.
This field is required.Sourcepub fn set_outpost_id(self, input: Option<String>) -> Self
pub fn set_outpost_id(self, input: Option<String>) -> Self
The ID or ARN of the Outpost.
Sourcepub fn get_outpost_id(&self) -> &Option<String>
pub fn get_outpost_id(&self) -> &Option<String>
The ID or ARN of the Outpost.
Sourcepub fn vpc_information_list(self, input: VpcInformation) -> Self
pub fn vpc_information_list(self, input: VpcInformation) -> Self
Appends an item to vpc_information_list.
To override the contents of this collection use set_vpc_information_list.
Information about the VPC used for private connectivity, including the VPC, its subnets, and an associated VPC endpoint. You can specify at most one entry.
Sourcepub fn set_vpc_information_list(
self,
input: Option<Vec<VpcInformation>>,
) -> Self
pub fn set_vpc_information_list( self, input: Option<Vec<VpcInformation>>, ) -> Self
Information about the VPC used for private connectivity, including the VPC, its subnets, and an associated VPC endpoint. You can specify at most one entry.
Sourcepub fn get_vpc_information_list(&self) -> &Option<Vec<VpcInformation>>
pub fn get_vpc_information_list(&self) -> &Option<Vec<VpcInformation>>
Information about the VPC used for private connectivity, including the VPC, its subnets, and an associated VPC endpoint. You can specify at most one entry.
Sourcepub fn build(self) -> Result<CreatePrivateConnectivityConfigInput, BuildError>
pub fn build(self) -> Result<CreatePrivateConnectivityConfigInput, BuildError>
Consumes the builder and constructs a CreatePrivateConnectivityConfigInput.
Sourceimpl CreatePrivateConnectivityConfigInputBuilder
impl CreatePrivateConnectivityConfigInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreatePrivateConnectivityConfigOutput, SdkError<CreatePrivateConnectivityConfigError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreatePrivateConnectivityConfigOutput, SdkError<CreatePrivateConnectivityConfigError, HttpResponse>>
Sends a request with this input using the given client.