#[non_exhaustive]pub struct CreateQuoteInputBuilder { /* private fields */ }Expand description
A builder for CreateQuoteInput.
Implementations
Sourceimpl CreateQuoteInputBuilder
impl CreateQuoteInputBuilder
Sourcepub fn outpost_identifier(self, input: impl Into<String>) -> Self
pub fn outpost_identifier(self, input: impl Into<String>) -> Self
The ID or ARN of the Outpost to associate with the quote. If not specified, the quote is created without an Outpost association.
Sourcepub fn set_outpost_identifier(self, input: Option<String>) -> Self
pub fn set_outpost_identifier(self, input: Option<String>) -> Self
The ID or ARN of the Outpost to associate with the quote. If not specified, the quote is created without an Outpost association.
Sourcepub fn get_outpost_identifier(&self) -> &Option<String>
pub fn get_outpost_identifier(&self) -> &Option<String>
The ID or ARN of the Outpost to associate with the quote. If not specified, the quote is created without an Outpost association.
Sourcepub fn country_code(self, input: impl Into<String>) -> Self
pub fn country_code(self, input: impl Into<String>) -> Self
The country code for the Outpost site location.
This field is required.Sourcepub fn set_country_code(self, input: Option<String>) -> Self
pub fn set_country_code(self, input: Option<String>) -> Self
The country code for the Outpost site location.
Sourcepub fn get_country_code(&self) -> &Option<String>
pub fn get_country_code(&self) -> &Option<String>
The country code for the Outpost site location.
Sourcepub fn requested_capacities(self, input: QuoteCapacity) -> Self
pub fn requested_capacities(self, input: QuoteCapacity) -> Self
Appends an item to requested_capacities.
To override the contents of this collection use set_requested_capacities.
The capacity requirements for the quote. Each entry specifies a capacity type (such as Amazon EC2), the unit, and the quantity. For Amazon EC2, the quantity is the number of additional instances to add to the Outpost. For Amazon EBS and Amazon S3, the quantity is the total desired end-state capacity of the Outpost.
Sourcepub fn set_requested_capacities(self, input: Option<Vec<QuoteCapacity>>) -> Self
pub fn set_requested_capacities(self, input: Option<Vec<QuoteCapacity>>) -> Self
The capacity requirements for the quote. Each entry specifies a capacity type (such as Amazon EC2), the unit, and the quantity. For Amazon EC2, the quantity is the number of additional instances to add to the Outpost. For Amazon EBS and Amazon S3, the quantity is the total desired end-state capacity of the Outpost.
Sourcepub fn get_requested_capacities(&self) -> &Option<Vec<QuoteCapacity>>
pub fn get_requested_capacities(&self) -> &Option<Vec<QuoteCapacity>>
The capacity requirements for the quote. Each entry specifies a capacity type (such as Amazon EC2), the unit, and the quantity. For Amazon EC2, the quantity is the number of additional instances to add to the Outpost. For Amazon EBS and Amazon S3, the quantity is the total desired end-state capacity of the Outpost.
Sourcepub fn requested_constraints(self, input: QuoteConstraint) -> Self
pub fn requested_constraints(self, input: QuoteConstraint) -> Self
Appends an item to requested_constraints.
To override the contents of this collection use set_requested_constraints.
The physical constraints for the quote, such as maximum number of racks, maximum power draw per rack, or maximum weight per rack.
Sourcepub fn set_requested_constraints(
self,
input: Option<Vec<QuoteConstraint>>,
) -> Self
pub fn set_requested_constraints( self, input: Option<Vec<QuoteConstraint>>, ) -> Self
The physical constraints for the quote, such as maximum number of racks, maximum power draw per rack, or maximum weight per rack.
Sourcepub fn get_requested_constraints(&self) -> &Option<Vec<QuoteConstraint>>
pub fn get_requested_constraints(&self) -> &Option<Vec<QuoteConstraint>>
The physical constraints for the quote, such as maximum number of racks, maximum power draw per rack, or maximum weight per rack.
Sourcepub fn requested_payment_options(self, input: PaymentOption) -> Self
pub fn requested_payment_options(self, input: PaymentOption) -> Self
Appends an item to requested_payment_options.
To override the contents of this collection use set_requested_payment_options.
The payment options to include in the quote pricing. If not specified, all available payment options are returned.
Sourcepub fn set_requested_payment_options(
self,
input: Option<Vec<PaymentOption>>,
) -> Self
pub fn set_requested_payment_options( self, input: Option<Vec<PaymentOption>>, ) -> Self
The payment options to include in the quote pricing. If not specified, all available payment options are returned.
Sourcepub fn get_requested_payment_options(&self) -> &Option<Vec<PaymentOption>>
pub fn get_requested_payment_options(&self) -> &Option<Vec<PaymentOption>>
The payment options to include in the quote pricing. If not specified, all available payment options are returned.
Sourcepub fn requested_payment_terms(self, input: PaymentTerm) -> Self
pub fn requested_payment_terms(self, input: PaymentTerm) -> Self
Appends an item to requested_payment_terms.
To override the contents of this collection use set_requested_payment_terms.
The payment terms to include in the quote pricing. If not specified, all available payment terms are returned.
Sourcepub fn set_requested_payment_terms(
self,
input: Option<Vec<PaymentTerm>>,
) -> Self
pub fn set_requested_payment_terms( self, input: Option<Vec<PaymentTerm>>, ) -> Self
The payment terms to include in the quote pricing. If not specified, all available payment terms are returned.
Sourcepub fn get_requested_payment_terms(&self) -> &Option<Vec<PaymentTerm>>
pub fn get_requested_payment_terms(&self) -> &Option<Vec<PaymentTerm>>
The payment terms to include in the quote pricing. If not specified, all available payment terms are returned.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
A description for the quote.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
A description for the quote.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
A description for the quote.
Sourcepub fn build(self) -> Result<CreateQuoteInput, BuildError>
pub fn build(self) -> Result<CreateQuoteInput, BuildError>
Consumes the builder and constructs a CreateQuoteInput.
Sourceimpl CreateQuoteInputBuilder
impl CreateQuoteInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateQuoteOutput, SdkError<CreateQuoteError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateQuoteOutput, SdkError<CreateQuoteError, HttpResponse>>
Sends a request with this input using the given client.