CreateQuoteInput

Struct CreateQuoteInput 

#[non_exhaustive]
pub struct CreateQuoteInput { pub outpost_identifier: Option<String>, pub country_code: Option<String>, pub requested_capacities: Option<Vec<QuoteCapacity>>, pub requested_constraints: Option<Vec<QuoteConstraint>>, pub requested_payment_options: Option<Vec<PaymentOption>>, pub requested_payment_terms: Option<Vec<PaymentTerm>>, pub description: Option<String>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
outpost_identifier: Option<String>

The ID or ARN of the Outpost to associate with the quote. If not specified, the quote is created without an Outpost association.

country_code: Option<String>

The country code for the Outpost site location.

requested_capacities: Option<Vec<QuoteCapacity>>

The capacity requirements for the quote. Each entry specifies a capacity type (such as Amazon EC2), the unit, and the quantity. For Amazon EC2, the quantity is the number of additional instances to add to the Outpost. For Amazon EBS and Amazon S3, the quantity is the total desired end-state capacity of the Outpost.

requested_constraints: Option<Vec<QuoteConstraint>>

The physical constraints for the quote, such as maximum number of racks, maximum power draw per rack, or maximum weight per rack.

requested_payment_options: Option<Vec<PaymentOption>>

The payment options to include in the quote pricing. If not specified, all available payment options are returned.

requested_payment_terms: Option<Vec<PaymentTerm>>

The payment terms to include in the quote pricing. If not specified, all available payment terms are returned.

description: Option<String>

A description for the quote.

Implementations

Source

impl CreateQuoteInput

pub fn outpost_identifier(&self) -> Option<&str>

The ID or ARN of the Outpost to associate with the quote. If not specified, the quote is created without an Outpost association.

pub fn country_code(&self) -> Option<&str>

The country code for the Outpost site location.

pub fn requested_capacities(&self) -> &[QuoteCapacity]

The capacity requirements for the quote. Each entry specifies a capacity type (such as Amazon EC2), the unit, and the quantity. For Amazon EC2, the quantity is the number of additional instances to add to the Outpost. For Amazon EBS and Amazon S3, the quantity is the total desired end-state capacity of the Outpost.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .requested_capacities.is_none().

pub fn requested_constraints(&self) -> &[QuoteConstraint]

The physical constraints for the quote, such as maximum number of racks, maximum power draw per rack, or maximum weight per rack.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .requested_constraints.is_none().

pub fn requested_payment_options(&self) -> &[PaymentOption]

The payment options to include in the quote pricing. If not specified, all available payment options are returned.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .requested_payment_options.is_none().

pub fn requested_payment_terms(&self) -> &[PaymentTerm]

The payment terms to include in the quote pricing. If not specified, all available payment terms are returned.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .requested_payment_terms.is_none().

pub fn description(&self) -> Option<&str>

A description for the quote.

Source

impl CreateQuoteInput

pub fn builder() -> CreateQuoteInputBuilder

Creates a new builder-style object to manufacture CreateQuoteInput.