#[non_exhaustive]pub struct UpdateQuoteInput {
pub quote_identifier: Option<String>,
pub outpost_identifier: Option<String>,
pub country_code: Option<String>,
pub requested_capacities: Option<Vec<QuoteCapacity>>,
pub requested_constraints: Option<Vec<QuoteConstraint>>,
pub requested_payment_options: Option<Vec<PaymentOption>>,
pub requested_payment_terms: Option<Vec<PaymentTerm>>,
pub description: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.quote_identifier: Option<String>The ID or ARN of the quote.
outpost_identifier: Option<String>The ID or ARN of the Outpost to associate with the quote. Specify an empty string to remove the Outpost association.
country_code: Option<String>The country code for the Outpost site location.
requested_capacities: Option<Vec<QuoteCapacity>>The updated capacity requirements for the quote.
requested_constraints: Option<Vec<QuoteConstraint>>The updated physical constraints for the quote.
requested_payment_options: Option<Vec<PaymentOption>>The updated payment options to include in the quote pricing.
requested_payment_terms: Option<Vec<PaymentTerm>>The updated payment terms to include in the quote pricing.
description: Option<String>A description for the quote.
Implementations
Sourceimpl UpdateQuoteInput
impl UpdateQuoteInput
Sourcepub fn quote_identifier(&self) -> Option<&str>
pub fn quote_identifier(&self) -> Option<&str>
The ID or ARN of the quote.
Sourcepub fn outpost_identifier(&self) -> Option<&str>
pub fn outpost_identifier(&self) -> Option<&str>
The ID or ARN of the Outpost to associate with the quote. Specify an empty string to remove the Outpost association.
Sourcepub fn country_code(&self) -> Option<&str>
pub fn country_code(&self) -> Option<&str>
The country code for the Outpost site location.
Sourcepub fn requested_capacities(&self) -> &[QuoteCapacity]
pub fn requested_capacities(&self) -> &[QuoteCapacity]
The updated capacity requirements for the quote.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .requested_capacities.is_none().
Sourcepub fn requested_constraints(&self) -> &[QuoteConstraint]
pub fn requested_constraints(&self) -> &[QuoteConstraint]
The updated physical constraints for the quote.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .requested_constraints.is_none().
Sourcepub fn requested_payment_options(&self) -> &[PaymentOption]
pub fn requested_payment_options(&self) -> &[PaymentOption]
The updated payment options to include in the quote pricing.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .requested_payment_options.is_none().
Sourcepub fn requested_payment_terms(&self) -> &[PaymentTerm]
pub fn requested_payment_terms(&self) -> &[PaymentTerm]
The updated payment terms to include in the quote pricing.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .requested_payment_terms.is_none().
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description for the quote.
Sourceimpl UpdateQuoteInput
impl UpdateQuoteInput
Sourcepub fn builder() -> UpdateQuoteInputBuilder
pub fn builder() -> UpdateQuoteInputBuilder
Creates a new builder-style object to manufacture UpdateQuoteInput.