#[non_exhaustive]pub struct CapacitySummaryBuilder { /* private fields */ }Expand description
A builder for CapacitySummary.
Implementations
Sourceimpl CapacitySummaryBuilder
impl CapacitySummaryBuilder
Sourcepub fn existing_capacities(self, input: QuoteCapacity) -> Self
pub fn existing_capacities(self, input: QuoteCapacity) -> Self
Appends an item to existing_capacities.
To override the contents of this collection use set_existing_capacities.
The existing capacities on the Outpost before the quote is fulfilled.
Sourcepub fn set_existing_capacities(self, input: Option<Vec<QuoteCapacity>>) -> Self
pub fn set_existing_capacities(self, input: Option<Vec<QuoteCapacity>>) -> Self
The existing capacities on the Outpost before the quote is fulfilled.
Sourcepub fn get_existing_capacities(&self) -> &Option<Vec<QuoteCapacity>>
pub fn get_existing_capacities(&self) -> &Option<Vec<QuoteCapacity>>
The existing capacities on the Outpost before the quote is fulfilled.
Sourcepub fn final_capacities(self, input: QuoteCapacity) -> Self
pub fn final_capacities(self, input: QuoteCapacity) -> Self
Appends an item to final_capacities.
To override the contents of this collection use set_final_capacities.
The final capacities on the Outpost after the quote is fulfilled.
Sourcepub fn set_final_capacities(self, input: Option<Vec<QuoteCapacity>>) -> Self
pub fn set_final_capacities(self, input: Option<Vec<QuoteCapacity>>) -> Self
The final capacities on the Outpost after the quote is fulfilled.
Sourcepub fn get_final_capacities(&self) -> &Option<Vec<QuoteCapacity>>
pub fn get_final_capacities(&self) -> &Option<Vec<QuoteCapacity>>
The final capacities on the Outpost after the quote is fulfilled.
Sourcepub fn capacity_change(self, input: QuoteCapacity) -> Self
pub fn capacity_change(self, input: QuoteCapacity) -> Self
Appends an item to capacity_change.
To override the contents of this collection use set_capacity_change.
The change in capacity between the existing and final state.
Sourcepub fn set_capacity_change(self, input: Option<Vec<QuoteCapacity>>) -> Self
pub fn set_capacity_change(self, input: Option<Vec<QuoteCapacity>>) -> Self
The change in capacity between the existing and final state.
Sourcepub fn get_capacity_change(&self) -> &Option<Vec<QuoteCapacity>>
pub fn get_capacity_change(&self) -> &Option<Vec<QuoteCapacity>>
The change in capacity between the existing and final state.
Sourcepub fn build(self) -> CapacitySummary
pub fn build(self) -> CapacitySummary
Consumes the builder and constructs a CapacitySummary.