#[non_exhaustive]pub struct PrivateConnectivityConfigBuilder { /* private fields */ }Expand description
A builder for PrivateConnectivityConfig.
Implementations
Sourceimpl PrivateConnectivityConfigBuilder
impl PrivateConnectivityConfigBuilder
Sourcepub fn role_arn(self, input: impl Into<String>) -> Self
pub fn role_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the service-linked role that Amazon Web Services Outposts creates and uses to provision and attach the network interfaces for private connectivity in your VPC. The role's permissions are scoped to the specific Outpost and VPC.
Sourcepub fn set_role_arn(self, input: Option<String>) -> Self
pub fn set_role_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the service-linked role that Amazon Web Services Outposts creates and uses to provision and attach the network interfaces for private connectivity in your VPC. The role's permissions are scoped to the specific Outpost and VPC.
Sourcepub fn get_role_arn(&self) -> &Option<String>
pub fn get_role_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the service-linked role that Amazon Web Services Outposts creates and uses to provision and attach the network interfaces for private connectivity in your VPC. The role's permissions are scoped to the specific Outpost and VPC.
Sourcepub fn private_connectivity_status(
self,
input: PrivateConnectivityStatus,
) -> Self
pub fn private_connectivity_status( self, input: PrivateConnectivityStatus, ) -> Self
The status of private connectivity for the Outpost. Valid values are ENABLED and DISABLED.
Sourcepub fn set_private_connectivity_status(
self,
input: Option<PrivateConnectivityStatus>,
) -> Self
pub fn set_private_connectivity_status( self, input: Option<PrivateConnectivityStatus>, ) -> Self
The status of private connectivity for the Outpost. Valid values are ENABLED and DISABLED.
Sourcepub fn get_private_connectivity_status(
&self,
) -> &Option<PrivateConnectivityStatus>
pub fn get_private_connectivity_status( &self, ) -> &Option<PrivateConnectivityStatus>
The status of private connectivity for the Outpost. Valid values are ENABLED and DISABLED.
Sourcepub fn vpc_information_list(self, input: VpcInformation) -> Self
pub fn vpc_information_list(self, input: VpcInformation) -> Self
Appends an item to vpc_information_list.
To override the contents of this collection use set_vpc_information_list.
Information about the VPC used for private connectivity.
Sourcepub fn set_vpc_information_list(
self,
input: Option<Vec<VpcInformation>>,
) -> Self
pub fn set_vpc_information_list( self, input: Option<Vec<VpcInformation>>, ) -> Self
Information about the VPC used for private connectivity.
Sourcepub fn get_vpc_information_list(&self) -> &Option<Vec<VpcInformation>>
pub fn get_vpc_information_list(&self) -> &Option<Vec<VpcInformation>>
Information about the VPC used for private connectivity.
Sourcepub fn provisioning_role_arn(self, input: impl Into<String>) -> Self
pub fn provisioning_role_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the provisioning role in your account that Amazon Web Services Outposts uses to establish the service link connection during Outpost installation. This field is present only when VPC endpoint-based provisioning is configured.
Sourcepub fn set_provisioning_role_arn(self, input: Option<String>) -> Self
pub fn set_provisioning_role_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the provisioning role in your account that Amazon Web Services Outposts uses to establish the service link connection during Outpost installation. This field is present only when VPC endpoint-based provisioning is configured.
Sourcepub fn get_provisioning_role_arn(&self) -> &Option<String>
pub fn get_provisioning_role_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the provisioning role in your account that Amazon Web Services Outposts uses to establish the service link connection during Outpost installation. This field is present only when VPC endpoint-based provisioning is configured.
Sourcepub fn build(self) -> PrivateConnectivityConfig
pub fn build(self) -> PrivateConnectivityConfig
Consumes the builder and constructs a PrivateConnectivityConfig.