QuoteBuilder

Struct QuoteBuilder 

#[non_exhaustive]
pub struct QuoteBuilder { /* private fields */ }
A builder for Quote.

Implementations

Source

impl QuoteBuilder

pub fn quote_id(self, input: impl Into<String>) -> Self

The ID of the quote.

pub fn set_quote_id(self, input: Option<String>) -> Self

The ID of the quote.

pub fn get_quote_id(&self) -> &Option<String>

The ID of the quote.

pub fn account_id(self, input: impl Into<String>) -> Self

The ID of the account that owns the quote.

pub fn set_account_id(self, input: Option<String>) -> Self

The ID of the account that owns the quote.

pub fn get_account_id(&self) -> &Option<String>

The ID of the account that owns the quote.

pub fn quote_status(self, input: QuoteStatus) -> Self

The status of the quote.

  • CREATED - The quote has been created and is available for review.

  • ORDER_SUBMITTED - An order has been submitted for the quote.

  • EXPIRED - The quote has expired and can no longer be used to submit an order.

pub fn set_quote_status(self, input: Option<QuoteStatus>) -> Self

The status of the quote.

  • CREATED - The quote has been created and is available for review.

  • ORDER_SUBMITTED - An order has been submitted for the quote.

  • EXPIRED - The quote has expired and can no longer be used to submit an order.

pub fn get_quote_status(&self) -> &Option<QuoteStatus>

The status of the quote.

  • CREATED - The quote has been created and is available for review.

  • ORDER_SUBMITTED - An order has been submitted for the quote.

  • EXPIRED - The quote has expired and can no longer be used to submit an order.

pub fn status_message(self, input: impl Into<String>) -> Self

A message about the status of the quote.

pub fn set_status_message(self, input: Option<String>) -> Self

A message about the status of the quote.

pub fn get_status_message(&self) -> &Option<String>

A message about the status of the quote.

pub fn outpost_arn(self, input: impl Into<String>) -> Self

The ARN of the Outpost associated with the quote.

pub fn set_outpost_arn(self, input: Option<String>) -> Self

The ARN of the Outpost associated with the quote.

pub fn get_outpost_arn(&self) -> &Option<String>

The ARN of the Outpost associated with the quote.

pub fn country_code(self, input: impl Into<String>) -> Self

The country code for the Outpost site location.

pub fn set_country_code(self, input: Option<String>) -> Self

The country code for the Outpost site location.

pub fn get_country_code(&self) -> &Option<String>

The country code for the Outpost site location.

pub fn requested_capacities(self, input: QuoteCapacity) -> Self

Appends an item to requested_capacities.

To override the contents of this collection use set_requested_capacities.

The capacity requirements specified in the quote request.

pub fn set_requested_capacities(self, input: Option<Vec<QuoteCapacity>>) -> Self

The capacity requirements specified in the quote request.

pub fn get_requested_capacities(&self) -> &Option<Vec<QuoteCapacity>>

The capacity requirements specified in the quote request.

pub fn requested_constraints(self, input: QuoteConstraint) -> Self

Appends an item to requested_constraints.

To override the contents of this collection use set_requested_constraints.

The physical constraints specified in the quote request.

pub fn set_requested_constraints( self, input: Option<Vec<QuoteConstraint>>, ) -> Self

The physical constraints specified in the quote request.

pub fn get_requested_constraints(&self) -> &Option<Vec<QuoteConstraint>>

The physical constraints specified in the quote request.

pub fn requested_payment_options(self, input: PaymentOption) -> Self

Appends an item to requested_payment_options.

To override the contents of this collection use set_requested_payment_options.

The payment options specified in the quote request.

pub fn set_requested_payment_options( self, input: Option<Vec<PaymentOption>>, ) -> Self

The payment options specified in the quote request.

pub fn get_requested_payment_options(&self) -> &Option<Vec<PaymentOption>>

The payment options specified in the quote request.

pub fn requested_payment_terms(self, input: PaymentTerm) -> Self

Appends an item to requested_payment_terms.

To override the contents of this collection use set_requested_payment_terms.

The payment terms specified in the quote request.

pub fn set_requested_payment_terms( self, input: Option<Vec<PaymentTerm>>, ) -> Self

The payment terms specified in the quote request.

pub fn get_requested_payment_terms(&self) -> &Option<Vec<PaymentTerm>>

The payment terms specified in the quote request.

pub fn quote_options(self, input: QuoteOption) -> Self

Appends an item to quote_options.

To override the contents of this collection use set_quote_options.

The configuration and pricing options for the quote. Each option includes capacity details, physical specifications, and pricing information.

pub fn set_quote_options(self, input: Option<Vec<QuoteOption>>) -> Self

The configuration and pricing options for the quote. Each option includes capacity details, physical specifications, and pricing information.

pub fn get_quote_options(&self) -> &Option<Vec<QuoteOption>>

The configuration and pricing options for the quote. Each option includes capacity details, physical specifications, and pricing information.

pub fn ordering_requirements(self, input: OrderingRequirement) -> Self

Appends an item to ordering_requirements.

To override the contents of this collection use set_ordering_requirements.

The requirements that must be met before an order can be submitted for the quote.

pub fn set_ordering_requirements( self, input: Option<Vec<OrderingRequirement>>, ) -> Self

The requirements that must be met before an order can be submitted for the quote.

pub fn get_ordering_requirements(&self) -> &Option<Vec<OrderingRequirement>>

The requirements that must be met before an order can be submitted for the quote.

pub fn submitted_order_id(self, input: impl Into<String>) -> Self

The ID of the order submitted for the quote.

pub fn set_submitted_order_id(self, input: Option<String>) -> Self

The ID of the order submitted for the quote.

pub fn get_submitted_order_id(&self) -> &Option<String>

The ID of the order submitted for the quote.

pub fn created_date(self, input: DateTime) -> Self

The date the quote was created.

pub fn set_created_date(self, input: Option<DateTime>) -> Self

The date the quote was created.

pub fn get_created_date(&self) -> &Option<DateTime>

The date the quote was created.

pub fn expiration_date(self, input: DateTime) -> Self

The date the quote expires.

pub fn set_expiration_date(self, input: Option<DateTime>) -> Self

The date the quote expires.

pub fn get_expiration_date(&self) -> &Option<DateTime>

The date the quote expires.

pub fn description(self, input: impl Into<String>) -> Self

The description of the quote.

pub fn set_description(self, input: Option<String>) -> Self

The description of the quote.

pub fn get_description(&self) -> &Option<String>

The description of the quote.

pub fn build(self) -> Quote

Consumes the builder and constructs a Quote.