#[non_exhaustive]pub struct QuoteCapacityBuilder { /* private fields */ }Expand description
A builder for QuoteCapacity.
Implementations
Sourceimpl QuoteCapacityBuilder
impl QuoteCapacityBuilder
Sourcepub fn quote_capacity_type(self, input: QuoteCapacityType) -> Self
pub fn quote_capacity_type(self, input: QuoteCapacityType) -> Self
The type of capacity. Valid values are EC2, EBS, and S3.
Sourcepub fn set_quote_capacity_type(self, input: Option<QuoteCapacityType>) -> Self
pub fn set_quote_capacity_type(self, input: Option<QuoteCapacityType>) -> Self
The type of capacity. Valid values are EC2, EBS, and S3.
Sourcepub fn get_quote_capacity_type(&self) -> &Option<QuoteCapacityType>
pub fn get_quote_capacity_type(&self) -> &Option<QuoteCapacityType>
The type of capacity. Valid values are EC2, EBS, and S3.
Sourcepub fn unit(self, input: impl Into<String>) -> Self
pub fn unit(self, input: impl Into<String>) -> Self
The unit of measurement for the capacity. For Amazon EC2, this is the instance type (for example, c5.24xlarge). For Amazon EBS and Amazon S3, this is the storage unit (for example, TiB for tebibytes).
Sourcepub fn set_unit(self, input: Option<String>) -> Self
pub fn set_unit(self, input: Option<String>) -> Self
The unit of measurement for the capacity. For Amazon EC2, this is the instance type (for example, c5.24xlarge). For Amazon EBS and Amazon S3, this is the storage unit (for example, TiB for tebibytes).
Sourcepub fn get_unit(&self) -> &Option<String>
pub fn get_unit(&self) -> &Option<String>
The unit of measurement for the capacity. For Amazon EC2, this is the instance type (for example, c5.24xlarge). For Amazon EBS and Amazon S3, this is the storage unit (for example, TiB for tebibytes).
Sourcepub fn quantity(self, input: f32) -> Self
pub fn quantity(self, input: f32) -> Self
The quantity of the specified capacity unit. For Amazon EC2, this is the number of additional instances to add to the Outpost. For Amazon EBS and Amazon S3, this is the total desired end-state capacity of the Outpost.
Sourcepub fn set_quantity(self, input: Option<f32>) -> Self
pub fn set_quantity(self, input: Option<f32>) -> Self
The quantity of the specified capacity unit. For Amazon EC2, this is the number of additional instances to add to the Outpost. For Amazon EBS and Amazon S3, this is the total desired end-state capacity of the Outpost.
Sourcepub fn get_quantity(&self) -> &Option<f32>
pub fn get_quantity(&self) -> &Option<f32>
The quantity of the specified capacity unit. For Amazon EC2, this is the number of additional instances to add to the Outpost. For Amazon EBS and Amazon S3, this is the total desired end-state capacity of the Outpost.
Sourcepub fn build(self) -> QuoteCapacity
pub fn build(self) -> QuoteCapacity
Consumes the builder and constructs a QuoteCapacity.