QuoteOptionBuilder

Struct QuoteOptionBuilder 

#[non_exhaustive]
pub struct QuoteOptionBuilder { /* private fields */ }
A builder for QuoteOption.

Implementations

Source

impl QuoteOptionBuilder

pub fn quote_option_identifier(self, input: impl Into<String>) -> Self

The ID of the quote option.

pub fn set_quote_option_identifier(self, input: Option<String>) -> Self

The ID of the quote option.

pub fn get_quote_option_identifier(&self) -> &Option<String>

The ID of the quote option.

pub fn capacities(self, input: QuoteCapacity) -> Self

Appends an item to capacities.

To override the contents of this collection use set_capacities.

The capacities included in this quote option.

pub fn set_capacities(self, input: Option<Vec<QuoteCapacity>>) -> Self

The capacities included in this quote option.

pub fn get_capacities(&self) -> &Option<Vec<QuoteCapacity>>

The capacities included in this quote option.

pub fn capacity_summary(self, input: CapacitySummary) -> Self

A summary of the existing, final, and changed capacity for this quote option.

pub fn set_capacity_summary(self, input: Option<CapacitySummary>) -> Self

A summary of the existing, final, and changed capacity for this quote option.

pub fn get_capacity_summary(&self) -> &Option<CapacitySummary>

A summary of the existing, final, and changed capacity for this quote option.

pub fn specifications(self, input: QuoteSpecification) -> Self

Appends an item to specifications.

To override the contents of this collection use set_specifications.

The physical specifications for the racks or servers in this quote option.

pub fn set_specifications(self, input: Option<Vec<QuoteSpecification>>) -> Self

The physical specifications for the racks or servers in this quote option.

pub fn get_specifications(&self) -> &Option<Vec<QuoteSpecification>>

The physical specifications for the racks or servers in this quote option.

pub fn pricing_options(self, input: PricingOption) -> Self

Appends an item to pricing_options.

To override the contents of this collection use set_pricing_options.

The pricing options for this quote option.

pub fn set_pricing_options(self, input: Option<Vec<PricingOption>>) -> Self

The pricing options for this quote option.

pub fn get_pricing_options(&self) -> &Option<Vec<PricingOption>>

The pricing options for this quote option.

pub fn build(self) -> QuoteOption

Consumes the builder and constructs a QuoteOption.