#[non_exhaustive]pub struct QuoteSpecificationBuilder { /* private fields */ }Expand description
A builder for QuoteSpecification.
Implementations
Sourceimpl QuoteSpecificationBuilder
impl QuoteSpecificationBuilder
Sourcepub fn quote_specification_type(self, input: QuoteSpecificationType) -> Self
pub fn quote_specification_type(self, input: QuoteSpecificationType) -> Self
The type of specification. Valid values are NEW_RACK, UPDATED_RACK, EXISTING_RACK, and SERVER.
Sourcepub fn set_quote_specification_type(
self,
input: Option<QuoteSpecificationType>,
) -> Self
pub fn set_quote_specification_type( self, input: Option<QuoteSpecificationType>, ) -> Self
The type of specification. Valid values are NEW_RACK, UPDATED_RACK, EXISTING_RACK, and SERVER.
Sourcepub fn get_quote_specification_type(&self) -> &Option<QuoteSpecificationType>
pub fn get_quote_specification_type(&self) -> &Option<QuoteSpecificationType>
The type of specification. Valid values are NEW_RACK, UPDATED_RACK, EXISTING_RACK, and SERVER.
Sourcepub fn existing_rack_specification_details(
self,
input: RackSpecificationDetails,
) -> Self
pub fn existing_rack_specification_details( self, input: RackSpecificationDetails, ) -> Self
The existing rack specification details, if the specification type is UPDATED_RACK or EXISTING_RACK.
Sourcepub fn set_existing_rack_specification_details(
self,
input: Option<RackSpecificationDetails>,
) -> Self
pub fn set_existing_rack_specification_details( self, input: Option<RackSpecificationDetails>, ) -> Self
The existing rack specification details, if the specification type is UPDATED_RACK or EXISTING_RACK.
Sourcepub fn get_existing_rack_specification_details(
&self,
) -> &Option<RackSpecificationDetails>
pub fn get_existing_rack_specification_details( &self, ) -> &Option<RackSpecificationDetails>
The existing rack specification details, if the specification type is UPDATED_RACK or EXISTING_RACK.
Sourcepub fn final_rack_specification_details(
self,
input: RackSpecificationDetails,
) -> Self
pub fn final_rack_specification_details( self, input: RackSpecificationDetails, ) -> Self
The final rack specification details after the quote is fulfilled.
Sourcepub fn set_final_rack_specification_details(
self,
input: Option<RackSpecificationDetails>,
) -> Self
pub fn set_final_rack_specification_details( self, input: Option<RackSpecificationDetails>, ) -> Self
The final rack specification details after the quote is fulfilled.
Sourcepub fn get_final_rack_specification_details(
&self,
) -> &Option<RackSpecificationDetails>
pub fn get_final_rack_specification_details( &self, ) -> &Option<RackSpecificationDetails>
The final rack specification details after the quote is fulfilled.
Sourcepub fn server_specification_details(
self,
input: ServerSpecificationDetails,
) -> Self
pub fn server_specification_details( self, input: ServerSpecificationDetails, ) -> Self
The server specification details, if the specification type is SERVER.
Sourcepub fn set_server_specification_details(
self,
input: Option<ServerSpecificationDetails>,
) -> Self
pub fn set_server_specification_details( self, input: Option<ServerSpecificationDetails>, ) -> Self
The server specification details, if the specification type is SERVER.
Sourcepub fn get_server_specification_details(
&self,
) -> &Option<ServerSpecificationDetails>
pub fn get_server_specification_details( &self, ) -> &Option<ServerSpecificationDetails>
The server specification details, if the specification type is SERVER.
Sourcepub fn build(self) -> QuoteSpecification
pub fn build(self) -> QuoteSpecification
Consumes the builder and constructs a QuoteSpecification.