#[non_exhaustive]pub struct ServerSpecificationDetailsBuilder { /* private fields */ }Expand description
A builder for ServerSpecificationDetails.
Implementations
Sourceimpl ServerSpecificationDetailsBuilder
impl ServerSpecificationDetailsBuilder
Sourcepub fn server_power_draw_kva(self, input: f32) -> Self
pub fn server_power_draw_kva(self, input: f32) -> Self
The maximum power draw of the server in kVA.
Sourcepub fn set_server_power_draw_kva(self, input: Option<f32>) -> Self
pub fn set_server_power_draw_kva(self, input: Option<f32>) -> Self
The maximum power draw of the server in kVA.
Sourcepub fn get_server_power_draw_kva(&self) -> &Option<f32>
pub fn get_server_power_draw_kva(&self) -> &Option<f32>
The maximum power draw of the server in kVA.
Sourcepub fn server_weight_lbs(self, input: f32) -> Self
pub fn server_weight_lbs(self, input: f32) -> Self
The weight of the server in pounds.
Sourcepub fn set_server_weight_lbs(self, input: Option<f32>) -> Self
pub fn set_server_weight_lbs(self, input: Option<f32>) -> Self
The weight of the server in pounds.
Sourcepub fn get_server_weight_lbs(&self) -> &Option<f32>
pub fn get_server_weight_lbs(&self) -> &Option<f32>
The weight of the server in pounds.
Sourcepub fn server_height_inches(self, input: f32) -> Self
pub fn server_height_inches(self, input: f32) -> Self
The height of the server in inches.
Sourcepub fn set_server_height_inches(self, input: Option<f32>) -> Self
pub fn set_server_height_inches(self, input: Option<f32>) -> Self
The height of the server in inches.
Sourcepub fn get_server_height_inches(&self) -> &Option<f32>
pub fn get_server_height_inches(&self) -> &Option<f32>
The height of the server in inches.
Sourcepub fn server_width_inches(self, input: f32) -> Self
pub fn server_width_inches(self, input: f32) -> Self
The width of the server in inches.
Sourcepub fn set_server_width_inches(self, input: Option<f32>) -> Self
pub fn set_server_width_inches(self, input: Option<f32>) -> Self
The width of the server in inches.
Sourcepub fn get_server_width_inches(&self) -> &Option<f32>
pub fn get_server_width_inches(&self) -> &Option<f32>
The width of the server in inches.
Sourcepub fn server_depth_inches(self, input: f32) -> Self
pub fn server_depth_inches(self, input: f32) -> Self
The depth of the server in inches.
Sourcepub fn set_server_depth_inches(self, input: Option<f32>) -> Self
pub fn set_server_depth_inches(self, input: Option<f32>) -> Self
The depth of the server in inches.
Sourcepub fn get_server_depth_inches(&self) -> &Option<f32>
pub fn get_server_depth_inches(&self) -> &Option<f32>
The depth of the server in inches.
Sourcepub fn rack_unit_height(self, input: RackUnitHeight) -> Self
pub fn rack_unit_height(self, input: RackUnitHeight) -> Self
The rack unit height of the server.
-
HEIGHT_2U- 2 rack units. -
HEIGHT_1U- 1 rack unit.
Sourcepub fn set_rack_unit_height(self, input: Option<RackUnitHeight>) -> Self
pub fn set_rack_unit_height(self, input: Option<RackUnitHeight>) -> Self
The rack unit height of the server.
-
HEIGHT_2U- 2 rack units. -
HEIGHT_1U- 1 rack unit.
Sourcepub fn get_rack_unit_height(&self) -> &Option<RackUnitHeight>
pub fn get_rack_unit_height(&self) -> &Option<RackUnitHeight>
The rack unit height of the server.
-
HEIGHT_2U- 2 rack units. -
HEIGHT_1U- 1 rack unit.
Sourcepub fn ec2_capacities(self, input: Ec2Capacity) -> Self
pub fn ec2_capacities(self, input: Ec2Capacity) -> Self
Appends an item to ec2_capacities.
To override the contents of this collection use set_ec2_capacities.
The Amazon EC2 capacities for the server.
Sourcepub fn set_ec2_capacities(self, input: Option<Vec<Ec2Capacity>>) -> Self
pub fn set_ec2_capacities(self, input: Option<Vec<Ec2Capacity>>) -> Self
The Amazon EC2 capacities for the server.
Sourcepub fn get_ec2_capacities(&self) -> &Option<Vec<Ec2Capacity>>
pub fn get_ec2_capacities(&self) -> &Option<Vec<Ec2Capacity>>
The Amazon EC2 capacities for the server.
Sourcepub fn build(self) -> ServerSpecificationDetails
pub fn build(self) -> ServerSpecificationDetails
Consumes the builder and constructs a ServerSpecificationDetails.