#[non_exhaustive]pub struct CapacitySummary {
pub existing_capacities: Option<Vec<QuoteCapacity>>,
pub final_capacities: Option<Vec<QuoteCapacity>>,
pub capacity_change: Option<Vec<QuoteCapacity>>,
}Expand description
A summary of the capacity changes for a quote option.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.existing_capacities: Option<Vec<QuoteCapacity>>The existing capacities on the Outpost before the quote is fulfilled.
final_capacities: Option<Vec<QuoteCapacity>>The final capacities on the Outpost after the quote is fulfilled.
capacity_change: Option<Vec<QuoteCapacity>>The change in capacity between the existing and final state.
Implementations
Sourceimpl CapacitySummary
impl CapacitySummary
Sourcepub fn existing_capacities(&self) -> &[QuoteCapacity]
pub fn existing_capacities(&self) -> &[QuoteCapacity]
The existing capacities on the Outpost before the quote is fulfilled.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .existing_capacities.is_none().
Sourcepub fn final_capacities(&self) -> &[QuoteCapacity]
pub fn final_capacities(&self) -> &[QuoteCapacity]
The final capacities on the Outpost after the quote is fulfilled.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .final_capacities.is_none().
Sourcepub fn capacity_change(&self) -> &[QuoteCapacity]
pub fn capacity_change(&self) -> &[QuoteCapacity]
The change in capacity between the existing and final state.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .capacity_change.is_none().
Sourceimpl CapacitySummary
impl CapacitySummary
Sourcepub fn builder() -> CapacitySummaryBuilder
pub fn builder() -> CapacitySummaryBuilder
Creates a new builder-style object to manufacture CapacitySummary.