#[non_exhaustive]pub struct DetailedInstanceTypeItem {
pub instance_type: Option<String>,
pub vcpus: Option<i32>,
pub memory_in_mib: i32,
pub network_performance: Option<String>,
pub form_factor_configs: Option<Vec<FormFactorConfig>>,
}Expand description
Information about an instance type that can be ordered for an Outpost, including hardware specifications and supported form factors.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.instance_type: Option<String>The instance type.
vcpus: Option<i32>The number of default VCPUs in the instance type.
memory_in_mib: i32The memory size of the instance type, in MiB.
network_performance: Option<String>The network performance of the instance type.
form_factor_configs: Option<Vec<FormFactorConfig>>The supported form factor and Outpost generation configurations for the instance type.
Implementations
Sourceimpl DetailedInstanceTypeItem
impl DetailedInstanceTypeItem
Sourcepub fn instance_type(&self) -> Option<&str>
pub fn instance_type(&self) -> Option<&str>
The instance type.
Sourcepub fn memory_in_mib(&self) -> i32
pub fn memory_in_mib(&self) -> i32
The memory size of the instance type, in MiB.
Sourcepub fn network_performance(&self) -> Option<&str>
pub fn network_performance(&self) -> Option<&str>
The network performance of the instance type.
Sourcepub fn form_factor_configs(&self) -> &[FormFactorConfig]
pub fn form_factor_configs(&self) -> &[FormFactorConfig]
The supported form factor and Outpost generation configurations for the instance type.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .form_factor_configs.is_none().
Sourceimpl DetailedInstanceTypeItem
impl DetailedInstanceTypeItem
Sourcepub fn builder() -> DetailedInstanceTypeItemBuilder
pub fn builder() -> DetailedInstanceTypeItemBuilder
Creates a new builder-style object to manufacture DetailedInstanceTypeItem.