#[non_exhaustive]pub struct OrderingRequirement {
pub status_message: Option<String>,
pub ordering_requirement_type: Option<OrderingRequirementType>,
pub status: Option<OrderingRequirementStatus>,
}Expand description
A requirement that must be met before an order can be submitted for a quote.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.status_message: Option<String>A message about the ordering requirement.
ordering_requirement_type: Option<OrderingRequirementType>The type of ordering requirement. Indicates which check failed or passed.
-
OUTPOST_ACTIVE_CHECK_ERROR- The Outpost must be in an active state. -
MAXIMUM_ALLOWED_ORDERS_CHECK_ERROR- The maximum number of allowed orders has been reached. -
VALID_ZIP_CODE_CHECK_ERROR- The site address must have a valid zip code. -
RACK_PHYSICAL_PROPERTIES_CHECK_ERROR- The rack physical properties do not meet requirements. -
OPERATING_ADDRESS_EXISTENCE_CHECK_ERROR- The site must have an operating address. -
SHIPPING_ADDRESS_EXISTENCE_CHECK_ERROR- The site must have a shipping address. -
COUNTRY_CODE_MISMATCH_CHECK_ERROR- The country code on the quote does not match the Outpost site country. -
OUTPOST_GENERATION_MISMATCH_ERROR- The Outpost generation does not match the requested configuration. -
OUTPOST_ID_MISSING_ON_QUOTE_ERROR- The quote must be associated with an Outpost before submitting an order. -
ENTERPRISE_SUPPORT_ERROR- Enterprise Support is required. -
SHIPPING_ADDRESS_MISSING_CONTACT_NAME_ERROR- The shipping address must have a contact name. -
SHIPPING_ADDRESS_MISSING_CONTACT_NUMBER_ERROR- The shipping address must have a contact phone number. -
SHIPPING_ADDRESS_MISSING_CONTACT_INFO_ERROR- The shipping address must have contact information. -
OUTPOST_STATE_CHANGED_ERROR- The Outpost state has changed since the quote was created. -
OUTPOST_NOT_FOUND_ERROR- The Outpost associated with the quote was not found. -
OUTPOST_RENEWAL_REQUIRED_ERROR- The Outpost requires a renewal before a new order can be submitted. -
UNSUPPORTED- The requirement type is not recognized.
status: Option<OrderingRequirementStatus>The status of the ordering requirement. Valid values are PASS, FAIL, and EXEMPT.
Implementations
Sourceimpl OrderingRequirement
impl OrderingRequirement
Sourcepub fn status_message(&self) -> Option<&str>
pub fn status_message(&self) -> Option<&str>
A message about the ordering requirement.
Sourcepub fn ordering_requirement_type(&self) -> Option<&OrderingRequirementType>
pub fn ordering_requirement_type(&self) -> Option<&OrderingRequirementType>
The type of ordering requirement. Indicates which check failed or passed.
-
OUTPOST_ACTIVE_CHECK_ERROR- The Outpost must be in an active state. -
MAXIMUM_ALLOWED_ORDERS_CHECK_ERROR- The maximum number of allowed orders has been reached. -
VALID_ZIP_CODE_CHECK_ERROR- The site address must have a valid zip code. -
RACK_PHYSICAL_PROPERTIES_CHECK_ERROR- The rack physical properties do not meet requirements. -
OPERATING_ADDRESS_EXISTENCE_CHECK_ERROR- The site must have an operating address. -
SHIPPING_ADDRESS_EXISTENCE_CHECK_ERROR- The site must have a shipping address. -
COUNTRY_CODE_MISMATCH_CHECK_ERROR- The country code on the quote does not match the Outpost site country. -
OUTPOST_GENERATION_MISMATCH_ERROR- The Outpost generation does not match the requested configuration. -
OUTPOST_ID_MISSING_ON_QUOTE_ERROR- The quote must be associated with an Outpost before submitting an order. -
ENTERPRISE_SUPPORT_ERROR- Enterprise Support is required. -
SHIPPING_ADDRESS_MISSING_CONTACT_NAME_ERROR- The shipping address must have a contact name. -
SHIPPING_ADDRESS_MISSING_CONTACT_NUMBER_ERROR- The shipping address must have a contact phone number. -
SHIPPING_ADDRESS_MISSING_CONTACT_INFO_ERROR- The shipping address must have contact information. -
OUTPOST_STATE_CHANGED_ERROR- The Outpost state has changed since the quote was created. -
OUTPOST_NOT_FOUND_ERROR- The Outpost associated with the quote was not found. -
OUTPOST_RENEWAL_REQUIRED_ERROR- The Outpost requires a renewal before a new order can be submitted. -
UNSUPPORTED- The requirement type is not recognized.
Sourcepub fn status(&self) -> Option<&OrderingRequirementStatus>
pub fn status(&self) -> Option<&OrderingRequirementStatus>
The status of the ordering requirement. Valid values are PASS, FAIL, and EXEMPT.
Sourceimpl OrderingRequirement
impl OrderingRequirement
Sourcepub fn builder() -> OrderingRequirementBuilder
pub fn builder() -> OrderingRequirementBuilder
Creates a new builder-style object to manufacture OrderingRequirement.