Quote

Struct Quote 

#[non_exhaustive]
pub struct Quote {
Show 16 fields pub quote_id: Option<String>, pub account_id: Option<String>, pub quote_status: Option<QuoteStatus>, pub status_message: Option<String>, pub outpost_arn: Option<String>, pub country_code: Option<String>, pub requested_capacities: Option<Vec<QuoteCapacity>>, pub requested_constraints: Option<Vec<QuoteConstraint>>, pub requested_payment_options: Option<Vec<PaymentOption>>, pub requested_payment_terms: Option<Vec<PaymentTerm>>, pub quote_options: Option<Vec<QuoteOption>>, pub ordering_requirements: Option<Vec<OrderingRequirement>>, pub submitted_order_id: Option<String>, pub created_date: Option<DateTime>, pub expiration_date: Option<DateTime>, pub description: Option<String>,
}
Information about a quote for an Outpost. A quote provides pricing and configuration options based on the requested capacity.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
quote_id: Option<String>

The ID of the quote.

account_id: Option<String>

The ID of the account that owns the quote.

quote_status: Option<QuoteStatus>

The status of the quote.

  • CREATED - The quote has been created and is available for review.

  • ORDER_SUBMITTED - An order has been submitted for the quote.

  • EXPIRED - The quote has expired and can no longer be used to submit an order.

status_message: Option<String>

A message about the status of the quote.

outpost_arn: Option<String>

The ARN of the Outpost associated with the quote.

country_code: Option<String>

The country code for the Outpost site location.

requested_capacities: Option<Vec<QuoteCapacity>>

The capacity requirements specified in the quote request.

requested_constraints: Option<Vec<QuoteConstraint>>

The physical constraints specified in the quote request.

requested_payment_options: Option<Vec<PaymentOption>>

The payment options specified in the quote request.

requested_payment_terms: Option<Vec<PaymentTerm>>

The payment terms specified in the quote request.

quote_options: Option<Vec<QuoteOption>>

The configuration and pricing options for the quote. Each option includes capacity details, physical specifications, and pricing information.

ordering_requirements: Option<Vec<OrderingRequirement>>

The requirements that must be met before an order can be submitted for the quote.

submitted_order_id: Option<String>

The ID of the order submitted for the quote.

created_date: Option<DateTime>

The date the quote was created.

expiration_date: Option<DateTime>

The date the quote expires.

description: Option<String>

The description of the quote.

Implementations

Source

impl Quote

pub fn quote_id(&self) -> Option<&str>

The ID of the quote.

pub fn account_id(&self) -> Option<&str>

The ID of the account that owns the quote.

pub fn quote_status(&self) -> Option<&QuoteStatus>

The status of the quote.

  • CREATED - The quote has been created and is available for review.

  • ORDER_SUBMITTED - An order has been submitted for the quote.

  • EXPIRED - The quote has expired and can no longer be used to submit an order.

pub fn status_message(&self) -> Option<&str>

A message about the status of the quote.

pub fn outpost_arn(&self) -> Option<&str>

The ARN of the Outpost associated with the quote.

pub fn country_code(&self) -> Option<&str>

The country code for the Outpost site location.

pub fn requested_capacities(&self) -> &[QuoteCapacity]

The capacity requirements specified in the quote request.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .requested_capacities.is_none().

pub fn requested_constraints(&self) -> &[QuoteConstraint]

The physical constraints specified in the quote request.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .requested_constraints.is_none().

pub fn requested_payment_options(&self) -> &[PaymentOption]

The payment options specified in the quote request.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .requested_payment_options.is_none().

pub fn requested_payment_terms(&self) -> &[PaymentTerm]

The payment terms specified in the quote request.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .requested_payment_terms.is_none().

pub fn quote_options(&self) -> &[QuoteOption]

The configuration and pricing options for the quote. Each option includes capacity details, physical specifications, and pricing information.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .quote_options.is_none().

pub fn ordering_requirements(&self) -> &[OrderingRequirement]

The requirements that must be met before an order can be submitted for the quote.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .ordering_requirements.is_none().

pub fn submitted_order_id(&self) -> Option<&str>

The ID of the order submitted for the quote.

pub fn created_date(&self) -> Option<&DateTime>

The date the quote was created.

pub fn expiration_date(&self) -> Option<&DateTime>

The date the quote expires.

pub fn description(&self) -> Option<&str>

The description of the quote.

Source

impl Quote

pub fn builder() -> QuoteBuilder

Creates a new builder-style object to manufacture Quote.