#[non_exhaustive]pub struct QuoteCapacity {
pub quote_capacity_type: Option<QuoteCapacityType>,
pub unit: Option<String>,
pub quantity: Option<f32>,
}Expand description
A capacity requirement for a quote. Specifies the type of capacity, the unit, and the quantity.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.quote_capacity_type: Option<QuoteCapacityType>The type of capacity. Valid values are EC2, EBS, and S3.
unit: Option<String>The unit of measurement for the capacity. For Amazon EC2, this is the instance type (for example, c5.24xlarge). For Amazon EBS and Amazon S3, this is the storage unit (for example, TiB for tebibytes).
quantity: Option<f32>The quantity of the specified capacity unit. For Amazon EC2, this is the number of additional instances to add to the Outpost. For Amazon EBS and Amazon S3, this is the total desired end-state capacity of the Outpost.
Implementations
Sourceimpl QuoteCapacity
impl QuoteCapacity
Sourcepub fn quote_capacity_type(&self) -> Option<&QuoteCapacityType>
pub fn quote_capacity_type(&self) -> Option<&QuoteCapacityType>
The type of capacity. Valid values are EC2, EBS, and S3.
Sourceimpl QuoteCapacity
impl QuoteCapacity
Sourcepub fn builder() -> QuoteCapacityBuilder
pub fn builder() -> QuoteCapacityBuilder
Creates a new builder-style object to manufacture QuoteCapacity.