QuoteOption

Struct QuoteOption 

#[non_exhaustive]
pub struct QuoteOption { pub quote_option_identifier: Option<String>, pub capacities: Option<Vec<QuoteCapacity>>, pub capacity_summary: Option<CapacitySummary>, pub specifications: Option<Vec<QuoteSpecification>>, pub pricing_options: Option<Vec<PricingOption>>, }
A configuration and pricing option for a quote. Each option includes the capacity breakdown, physical specifications for the racks or servers, and pricing details.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
quote_option_identifier: Option<String>

The ID of the quote option.

capacities: Option<Vec<QuoteCapacity>>

The capacities included in this quote option.

capacity_summary: Option<CapacitySummary>

A summary of the existing, final, and changed capacity for this quote option.

specifications: Option<Vec<QuoteSpecification>>

The physical specifications for the racks or servers in this quote option.

pricing_options: Option<Vec<PricingOption>>

The pricing options for this quote option.

Implementations

Source

impl QuoteOption

pub fn quote_option_identifier(&self) -> Option<&str>

The ID of the quote option.

pub fn capacities(&self) -> &[QuoteCapacity]

The capacities included in this quote option.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .capacities.is_none().

pub fn capacity_summary(&self) -> Option<&CapacitySummary>

A summary of the existing, final, and changed capacity for this quote option.

pub fn specifications(&self) -> &[QuoteSpecification]

The physical specifications for the racks or servers in this quote option.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .specifications.is_none().

pub fn pricing_options(&self) -> &[PricingOption]

The pricing options for this quote option.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .pricing_options.is_none().

Source

impl QuoteOption

pub fn builder() -> QuoteOptionBuilder

Creates a new builder-style object to manufacture QuoteOption.