QuoteSpecification

Struct QuoteSpecification 

#[non_exhaustive]
pub struct QuoteSpecification { pub quote_specification_type: Option<QuoteSpecificationType>, pub existing_rack_specification_details: Option<RackSpecificationDetails>, pub final_rack_specification_details: Option<RackSpecificationDetails>, pub server_specification_details: Option<ServerSpecificationDetails>, }
A physical specification for a quote option. Describes the rack or server configuration that would be deployed.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
quote_specification_type: Option<QuoteSpecificationType>

The type of specification. Valid values are NEW_RACK, UPDATED_RACK, EXISTING_RACK, and SERVER.

existing_rack_specification_details: Option<RackSpecificationDetails>

The existing rack specification details, if the specification type is UPDATED_RACK or EXISTING_RACK.

final_rack_specification_details: Option<RackSpecificationDetails>

The final rack specification details after the quote is fulfilled.

server_specification_details: Option<ServerSpecificationDetails>

The server specification details, if the specification type is SERVER.

Implementations

Source

impl QuoteSpecification

pub fn quote_specification_type(&self) -> Option<&QuoteSpecificationType>

The type of specification. Valid values are NEW_RACK, UPDATED_RACK, EXISTING_RACK, and SERVER.

pub fn existing_rack_specification_details( &self, ) -> Option<&RackSpecificationDetails>

The existing rack specification details, if the specification type is UPDATED_RACK or EXISTING_RACK.

pub fn final_rack_specification_details( &self, ) -> Option<&RackSpecificationDetails>

The final rack specification details after the quote is fulfilled.

pub fn server_specification_details( &self, ) -> Option<&ServerSpecificationDetails>

The server specification details, if the specification type is SERVER.

Source

impl QuoteSpecification

pub fn builder() -> QuoteSpecificationBuilder

Creates a new builder-style object to manufacture QuoteSpecification.