#[non_exhaustive]pub struct QuoteSummary {Show 15 fields
pub quote_id: Option<String>,
pub account_id: Option<String>,
pub quote_status: Option<QuoteStatus>,
pub status_message: Option<String>,
pub outpost_arn: Option<String>,
pub country_code: Option<String>,
pub requested_capacities: Option<Vec<QuoteCapacity>>,
pub requested_constraints: Option<Vec<QuoteConstraint>>,
pub requested_payment_options: Option<Vec<PaymentOption>>,
pub requested_payment_terms: Option<Vec<PaymentTerm>>,
pub quote_options: Option<Vec<QuoteOption>>,
pub submitted_order_id: Option<String>,
pub created_date: Option<DateTime>,
pub expiration_date: Option<DateTime>,
pub description: Option<String>,
}Expand description
Summary information about a quote.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.quote_id: Option<String>The ID of the quote.
account_id: Option<String>The ID of the account that owns the quote.
quote_status: Option<QuoteStatus>The status of the quote.
status_message: Option<String>A message about the status of the quote.
outpost_arn: Option<String>The ARN of the Outpost associated with the quote.
country_code: Option<String>The country code for the Outpost site location.
requested_capacities: Option<Vec<QuoteCapacity>>The capacity requirements specified in the quote request.
requested_constraints: Option<Vec<QuoteConstraint>>The physical constraints specified in the quote request.
requested_payment_options: Option<Vec<PaymentOption>>The payment options specified in the quote request.
requested_payment_terms: Option<Vec<PaymentTerm>>The payment terms specified in the quote request.
quote_options: Option<Vec<QuoteOption>>The configuration and pricing options for the quote.
submitted_order_id: Option<String>The ID of the order submitted for the quote.
created_date: Option<DateTime>The date the quote was created.
expiration_date: Option<DateTime>The date the quote expires.
description: Option<String>The description of the quote.
Implementations
Sourceimpl QuoteSummary
impl QuoteSummary
Sourcepub fn account_id(&self) -> Option<&str>
pub fn account_id(&self) -> Option<&str>
The ID of the account that owns the quote.
Sourcepub fn quote_status(&self) -> Option<&QuoteStatus>
pub fn quote_status(&self) -> Option<&QuoteStatus>
The status of the quote.
Sourcepub fn status_message(&self) -> Option<&str>
pub fn status_message(&self) -> Option<&str>
A message about the status of the quote.
Sourcepub fn outpost_arn(&self) -> Option<&str>
pub fn outpost_arn(&self) -> Option<&str>
The ARN of the Outpost associated with the quote.
Sourcepub fn country_code(&self) -> Option<&str>
pub fn country_code(&self) -> Option<&str>
The country code for the Outpost site location.
Sourcepub fn requested_capacities(&self) -> &[QuoteCapacity]
pub fn requested_capacities(&self) -> &[QuoteCapacity]
The capacity requirements specified in the quote request.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .requested_capacities.is_none().
Sourcepub fn requested_constraints(&self) -> &[QuoteConstraint]
pub fn requested_constraints(&self) -> &[QuoteConstraint]
The physical constraints specified in the quote request.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .requested_constraints.is_none().
Sourcepub fn requested_payment_options(&self) -> &[PaymentOption]
pub fn requested_payment_options(&self) -> &[PaymentOption]
The payment options specified in the quote request.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .requested_payment_options.is_none().
Sourcepub fn requested_payment_terms(&self) -> &[PaymentTerm]
pub fn requested_payment_terms(&self) -> &[PaymentTerm]
The payment terms specified in the quote request.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .requested_payment_terms.is_none().
Sourcepub fn quote_options(&self) -> &[QuoteOption]
pub fn quote_options(&self) -> &[QuoteOption]
The configuration and pricing options for the quote.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .quote_options.is_none().
Sourcepub fn submitted_order_id(&self) -> Option<&str>
pub fn submitted_order_id(&self) -> Option<&str>
The ID of the order submitted for the quote.
Sourcepub fn created_date(&self) -> Option<&DateTime>
pub fn created_date(&self) -> Option<&DateTime>
The date the quote was created.
Sourcepub fn expiration_date(&self) -> Option<&DateTime>
pub fn expiration_date(&self) -> Option<&DateTime>
The date the quote expires.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the quote.
Sourceimpl QuoteSummary
impl QuoteSummary
Sourcepub fn builder() -> QuoteSummaryBuilder
pub fn builder() -> QuoteSummaryBuilder
Creates a new builder-style object to manufacture QuoteSummary.