#[non_exhaustive]pub struct RackSpecificationDetails {
pub rack_id: Option<String>,
pub rack_use: Option<QuoteRackUseType>,
pub rack_power_draw_kva: Option<f32>,
pub rack_weight_lbs: Option<f32>,
pub rack_height_inches: Option<f32>,
pub rack_width_inches: Option<f32>,
pub rack_depth_inches: Option<f32>,
pub rack_unit_height: Option<RackUnitHeight>,
pub ec2_capacities: Option<Vec<Ec2Capacity>>,
}Expand description
The physical specification details for a rack in a quote option.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rack_id: Option<String>The ID of the rack.
rack_use: Option<QuoteRackUseType>The use of the rack. Valid values are COMPUTE and NETWORKING.
rack_power_draw_kva: Option<f32>The maximum power draw of the rack in kVA.
rack_weight_lbs: Option<f32>The weight of the rack in pounds.
rack_height_inches: Option<f32>The height of the rack in inches.
rack_width_inches: Option<f32>The width of the rack in inches.
rack_depth_inches: Option<f32>The depth of the rack in inches.
rack_unit_height: Option<RackUnitHeight>The rack unit height.
-
HEIGHT_42U- 42 rack units. -
HEIGHT_2U- 2 rack units. -
HEIGHT_1U- 1 rack unit.
ec2_capacities: Option<Vec<Ec2Capacity>>The Amazon EC2 capacities for the rack.
Implementations
Sourceimpl RackSpecificationDetails
impl RackSpecificationDetails
Sourcepub fn rack_use(&self) -> Option<&QuoteRackUseType>
pub fn rack_use(&self) -> Option<&QuoteRackUseType>
The use of the rack. Valid values are COMPUTE and NETWORKING.
Sourcepub fn rack_power_draw_kva(&self) -> Option<f32>
pub fn rack_power_draw_kva(&self) -> Option<f32>
The maximum power draw of the rack in kVA.
Sourcepub fn rack_weight_lbs(&self) -> Option<f32>
pub fn rack_weight_lbs(&self) -> Option<f32>
The weight of the rack in pounds.
Sourcepub fn rack_height_inches(&self) -> Option<f32>
pub fn rack_height_inches(&self) -> Option<f32>
The height of the rack in inches.
Sourcepub fn rack_width_inches(&self) -> Option<f32>
pub fn rack_width_inches(&self) -> Option<f32>
The width of the rack in inches.
Sourcepub fn rack_depth_inches(&self) -> Option<f32>
pub fn rack_depth_inches(&self) -> Option<f32>
The depth of the rack in inches.
Sourcepub fn rack_unit_height(&self) -> Option<&RackUnitHeight>
pub fn rack_unit_height(&self) -> Option<&RackUnitHeight>
The rack unit height.
-
HEIGHT_42U- 42 rack units. -
HEIGHT_2U- 2 rack units. -
HEIGHT_1U- 1 rack unit.
Sourcepub fn ec2_capacities(&self) -> &[Ec2Capacity]
pub fn ec2_capacities(&self) -> &[Ec2Capacity]
The Amazon EC2 capacities for the rack.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .ec2_capacities.is_none().
Sourceimpl RackSpecificationDetails
impl RackSpecificationDetails
Sourcepub fn builder() -> RackSpecificationDetailsBuilder
pub fn builder() -> RackSpecificationDetailsBuilder
Creates a new builder-style object to manufacture RackSpecificationDetails.