#[non_exhaustive]pub struct VpcInformation {
pub vpc_id: Option<String>,
pub subnet_ids: Option<Vec<String>>,
pub vpc_endpoint_id: Option<String>,
}Expand description
Information about a VPC used for private connectivity, including its subnets and an associated VPC endpoint.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.vpc_id: Option<String>The ID of the VPC used for private connectivity.
subnet_ids: Option<Vec<String>>The IDs of the subnets associated with the VPC endpoint. Currently, only one subnet is supported.
vpc_endpoint_id: Option<String>The ID of the interface VPC endpoint for the Amazon Web Services Outposts service. When specified, the endpoint must be in the available state and the specified subnets must be associated with it.
Implementations
Sourceimpl VpcInformation
impl VpcInformation
Sourcepub fn subnet_ids(&self) -> &[String]
pub fn subnet_ids(&self) -> &[String]
The IDs of the subnets associated with the VPC endpoint. Currently, only one subnet is supported.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .subnet_ids.is_none().
Sourcepub fn vpc_endpoint_id(&self) -> Option<&str>
pub fn vpc_endpoint_id(&self) -> Option<&str>
The ID of the interface VPC endpoint for the Amazon Web Services Outposts service. When specified, the endpoint must be in the available state and the specified subnets must be associated with it.
Sourceimpl VpcInformation
impl VpcInformation
Sourcepub fn builder() -> VpcInformationBuilder
pub fn builder() -> VpcInformationBuilder
Creates a new builder-style object to manufacture VpcInformation.