#[non_exhaustive]pub struct QuoteBuilder { /* private fields */ }Expand description
A builder for Quote.
Implementations
Sourceimpl QuoteBuilder
impl QuoteBuilder
Sourcepub fn set_quote_id(self, input: Option<String>) -> Self
pub fn set_quote_id(self, input: Option<String>) -> Self
The ID of the quote.
Sourcepub fn get_quote_id(&self) -> &Option<String>
pub fn get_quote_id(&self) -> &Option<String>
The ID of the quote.
Sourcepub fn account_id(self, input: impl Into<String>) -> Self
pub fn account_id(self, input: impl Into<String>) -> Self
The ID of the account that owns the quote.
Sourcepub fn set_account_id(self, input: Option<String>) -> Self
pub fn set_account_id(self, input: Option<String>) -> Self
The ID of the account that owns the quote.
Sourcepub fn get_account_id(&self) -> &Option<String>
pub fn get_account_id(&self) -> &Option<String>
The ID of the account that owns the quote.
Sourcepub fn quote_status(self, input: QuoteStatus) -> Self
pub fn quote_status(self, input: QuoteStatus) -> Self
The status of the quote.
-
CREATED- The quote has been created and is available for review. -
ORDER_SUBMITTED- An order has been submitted for the quote. -
EXPIRED- The quote has expired and can no longer be used to submit an order.
Sourcepub fn set_quote_status(self, input: Option<QuoteStatus>) -> Self
pub fn set_quote_status(self, input: Option<QuoteStatus>) -> Self
The status of the quote.
-
CREATED- The quote has been created and is available for review. -
ORDER_SUBMITTED- An order has been submitted for the quote. -
EXPIRED- The quote has expired and can no longer be used to submit an order.
Sourcepub fn get_quote_status(&self) -> &Option<QuoteStatus>
pub fn get_quote_status(&self) -> &Option<QuoteStatus>
The status of the quote.
-
CREATED- The quote has been created and is available for review. -
ORDER_SUBMITTED- An order has been submitted for the quote. -
EXPIRED- The quote has expired and can no longer be used to submit an order.
Sourcepub fn status_message(self, input: impl Into<String>) -> Self
pub fn status_message(self, input: impl Into<String>) -> Self
A message about the status of the quote.
Sourcepub fn set_status_message(self, input: Option<String>) -> Self
pub fn set_status_message(self, input: Option<String>) -> Self
A message about the status of the quote.
Sourcepub fn get_status_message(&self) -> &Option<String>
pub fn get_status_message(&self) -> &Option<String>
A message about the status of the quote.
Sourcepub fn outpost_arn(self, input: impl Into<String>) -> Self
pub fn outpost_arn(self, input: impl Into<String>) -> Self
The ARN of the Outpost associated with the quote.
Sourcepub fn set_outpost_arn(self, input: Option<String>) -> Self
pub fn set_outpost_arn(self, input: Option<String>) -> Self
The ARN of the Outpost associated with the quote.
Sourcepub fn get_outpost_arn(&self) -> &Option<String>
pub fn get_outpost_arn(&self) -> &Option<String>
The ARN of the Outpost associated with the quote.
Sourcepub fn country_code(self, input: impl Into<String>) -> Self
pub fn country_code(self, input: impl Into<String>) -> Self
The country code for the Outpost site location.
Sourcepub fn set_country_code(self, input: Option<String>) -> Self
pub fn set_country_code(self, input: Option<String>) -> Self
The country code for the Outpost site location.
Sourcepub fn get_country_code(&self) -> &Option<String>
pub fn get_country_code(&self) -> &Option<String>
The country code for the Outpost site location.
Sourcepub fn requested_capacities(self, input: QuoteCapacity) -> Self
pub fn requested_capacities(self, input: QuoteCapacity) -> Self
Appends an item to requested_capacities.
To override the contents of this collection use set_requested_capacities.
The capacity requirements specified in the quote request.
Sourcepub fn set_requested_capacities(self, input: Option<Vec<QuoteCapacity>>) -> Self
pub fn set_requested_capacities(self, input: Option<Vec<QuoteCapacity>>) -> Self
The capacity requirements specified in the quote request.
Sourcepub fn get_requested_capacities(&self) -> &Option<Vec<QuoteCapacity>>
pub fn get_requested_capacities(&self) -> &Option<Vec<QuoteCapacity>>
The capacity requirements specified in the quote request.
Sourcepub fn requested_constraints(self, input: QuoteConstraint) -> Self
pub fn requested_constraints(self, input: QuoteConstraint) -> Self
Appends an item to requested_constraints.
To override the contents of this collection use set_requested_constraints.
The physical constraints specified in the quote request.
Sourcepub fn set_requested_constraints(
self,
input: Option<Vec<QuoteConstraint>>,
) -> Self
pub fn set_requested_constraints( self, input: Option<Vec<QuoteConstraint>>, ) -> Self
The physical constraints specified in the quote request.
Sourcepub fn get_requested_constraints(&self) -> &Option<Vec<QuoteConstraint>>
pub fn get_requested_constraints(&self) -> &Option<Vec<QuoteConstraint>>
The physical constraints specified in the quote request.
Sourcepub fn requested_payment_options(self, input: PaymentOption) -> Self
pub fn requested_payment_options(self, input: PaymentOption) -> Self
Appends an item to requested_payment_options.
To override the contents of this collection use set_requested_payment_options.
The payment options specified in the quote request.
Sourcepub fn set_requested_payment_options(
self,
input: Option<Vec<PaymentOption>>,
) -> Self
pub fn set_requested_payment_options( self, input: Option<Vec<PaymentOption>>, ) -> Self
The payment options specified in the quote request.
Sourcepub fn get_requested_payment_options(&self) -> &Option<Vec<PaymentOption>>
pub fn get_requested_payment_options(&self) -> &Option<Vec<PaymentOption>>
The payment options specified in the quote request.
Sourcepub fn requested_payment_terms(self, input: PaymentTerm) -> Self
pub fn requested_payment_terms(self, input: PaymentTerm) -> Self
Appends an item to requested_payment_terms.
To override the contents of this collection use set_requested_payment_terms.
The payment terms specified in the quote request.
Sourcepub fn set_requested_payment_terms(
self,
input: Option<Vec<PaymentTerm>>,
) -> Self
pub fn set_requested_payment_terms( self, input: Option<Vec<PaymentTerm>>, ) -> Self
The payment terms specified in the quote request.
Sourcepub fn get_requested_payment_terms(&self) -> &Option<Vec<PaymentTerm>>
pub fn get_requested_payment_terms(&self) -> &Option<Vec<PaymentTerm>>
The payment terms specified in the quote request.
Sourcepub fn quote_options(self, input: QuoteOption) -> Self
pub fn quote_options(self, input: QuoteOption) -> Self
Appends an item to quote_options.
To override the contents of this collection use set_quote_options.
The configuration and pricing options for the quote. Each option includes capacity details, physical specifications, and pricing information.
Sourcepub fn set_quote_options(self, input: Option<Vec<QuoteOption>>) -> Self
pub fn set_quote_options(self, input: Option<Vec<QuoteOption>>) -> Self
The configuration and pricing options for the quote. Each option includes capacity details, physical specifications, and pricing information.
Sourcepub fn get_quote_options(&self) -> &Option<Vec<QuoteOption>>
pub fn get_quote_options(&self) -> &Option<Vec<QuoteOption>>
The configuration and pricing options for the quote. Each option includes capacity details, physical specifications, and pricing information.
Sourcepub fn ordering_requirements(self, input: OrderingRequirement) -> Self
pub fn ordering_requirements(self, input: OrderingRequirement) -> Self
Appends an item to ordering_requirements.
To override the contents of this collection use set_ordering_requirements.
The requirements that must be met before an order can be submitted for the quote.
Sourcepub fn set_ordering_requirements(
self,
input: Option<Vec<OrderingRequirement>>,
) -> Self
pub fn set_ordering_requirements( self, input: Option<Vec<OrderingRequirement>>, ) -> Self
The requirements that must be met before an order can be submitted for the quote.
Sourcepub fn get_ordering_requirements(&self) -> &Option<Vec<OrderingRequirement>>
pub fn get_ordering_requirements(&self) -> &Option<Vec<OrderingRequirement>>
The requirements that must be met before an order can be submitted for the quote.
Sourcepub fn submitted_order_id(self, input: impl Into<String>) -> Self
pub fn submitted_order_id(self, input: impl Into<String>) -> Self
The ID of the order submitted for the quote.
Sourcepub fn set_submitted_order_id(self, input: Option<String>) -> Self
pub fn set_submitted_order_id(self, input: Option<String>) -> Self
The ID of the order submitted for the quote.
Sourcepub fn get_submitted_order_id(&self) -> &Option<String>
pub fn get_submitted_order_id(&self) -> &Option<String>
The ID of the order submitted for the quote.
Sourcepub fn created_date(self, input: DateTime) -> Self
pub fn created_date(self, input: DateTime) -> Self
The date the quote was created.
Sourcepub fn set_created_date(self, input: Option<DateTime>) -> Self
pub fn set_created_date(self, input: Option<DateTime>) -> Self
The date the quote was created.
Sourcepub fn get_created_date(&self) -> &Option<DateTime>
pub fn get_created_date(&self) -> &Option<DateTime>
The date the quote was created.
Sourcepub fn expiration_date(self, input: DateTime) -> Self
pub fn expiration_date(self, input: DateTime) -> Self
The date the quote expires.
Sourcepub fn set_expiration_date(self, input: Option<DateTime>) -> Self
pub fn set_expiration_date(self, input: Option<DateTime>) -> Self
The date the quote expires.
Sourcepub fn get_expiration_date(&self) -> &Option<DateTime>
pub fn get_expiration_date(&self) -> &Option<DateTime>
The date the quote expires.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The description of the quote.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The description of the quote.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The description of the quote.