#[non_exhaustive]pub struct QuoteOptionBuilder { /* private fields */ }Expand description
A builder for QuoteOption.
Implementations
Sourceimpl QuoteOptionBuilder
impl QuoteOptionBuilder
Sourcepub fn quote_option_identifier(self, input: impl Into<String>) -> Self
pub fn quote_option_identifier(self, input: impl Into<String>) -> Self
The ID of the quote option.
Sourcepub fn set_quote_option_identifier(self, input: Option<String>) -> Self
pub fn set_quote_option_identifier(self, input: Option<String>) -> Self
The ID of the quote option.
Sourcepub fn get_quote_option_identifier(&self) -> &Option<String>
pub fn get_quote_option_identifier(&self) -> &Option<String>
The ID of the quote option.
Sourcepub fn capacities(self, input: QuoteCapacity) -> Self
pub fn capacities(self, input: QuoteCapacity) -> Self
Appends an item to capacities.
To override the contents of this collection use set_capacities.
The capacities included in this quote option.
Sourcepub fn set_capacities(self, input: Option<Vec<QuoteCapacity>>) -> Self
pub fn set_capacities(self, input: Option<Vec<QuoteCapacity>>) -> Self
The capacities included in this quote option.
Sourcepub fn get_capacities(&self) -> &Option<Vec<QuoteCapacity>>
pub fn get_capacities(&self) -> &Option<Vec<QuoteCapacity>>
The capacities included in this quote option.
Sourcepub fn capacity_summary(self, input: CapacitySummary) -> Self
pub fn capacity_summary(self, input: CapacitySummary) -> Self
A summary of the existing, final, and changed capacity for this quote option.
Sourcepub fn set_capacity_summary(self, input: Option<CapacitySummary>) -> Self
pub fn set_capacity_summary(self, input: Option<CapacitySummary>) -> Self
A summary of the existing, final, and changed capacity for this quote option.
Sourcepub fn get_capacity_summary(&self) -> &Option<CapacitySummary>
pub fn get_capacity_summary(&self) -> &Option<CapacitySummary>
A summary of the existing, final, and changed capacity for this quote option.
Sourcepub fn specifications(self, input: QuoteSpecification) -> Self
pub fn specifications(self, input: QuoteSpecification) -> Self
Appends an item to specifications.
To override the contents of this collection use set_specifications.
The physical specifications for the racks or servers in this quote option.
Sourcepub fn set_specifications(self, input: Option<Vec<QuoteSpecification>>) -> Self
pub fn set_specifications(self, input: Option<Vec<QuoteSpecification>>) -> Self
The physical specifications for the racks or servers in this quote option.
Sourcepub fn get_specifications(&self) -> &Option<Vec<QuoteSpecification>>
pub fn get_specifications(&self) -> &Option<Vec<QuoteSpecification>>
The physical specifications for the racks or servers in this quote option.
Sourcepub fn pricing_options(self, input: PricingOption) -> Self
pub fn pricing_options(self, input: PricingOption) -> Self
Appends an item to pricing_options.
To override the contents of this collection use set_pricing_options.
The pricing options for this quote option.
Sourcepub fn set_pricing_options(self, input: Option<Vec<PricingOption>>) -> Self
pub fn set_pricing_options(self, input: Option<Vec<PricingOption>>) -> Self
The pricing options for this quote option.
Sourcepub fn get_pricing_options(&self) -> &Option<Vec<PricingOption>>
pub fn get_pricing_options(&self) -> &Option<Vec<PricingOption>>
The pricing options for this quote option.
Sourcepub fn build(self) -> QuoteOption
pub fn build(self) -> QuoteOption
Consumes the builder and constructs a QuoteOption.