#[non_exhaustive]pub struct QuoteSpecification {
pub quote_specification_type: Option<QuoteSpecificationType>,
pub existing_rack_specification_details: Option<RackSpecificationDetails>,
pub final_rack_specification_details: Option<RackSpecificationDetails>,
pub server_specification_details: Option<ServerSpecificationDetails>,
}Expand description
A physical specification for a quote option. Describes the rack or server configuration that would be deployed.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.quote_specification_type: Option<QuoteSpecificationType>The type of specification. Valid values are NEW_RACK, UPDATED_RACK, EXISTING_RACK, and SERVER.
existing_rack_specification_details: Option<RackSpecificationDetails>The existing rack specification details, if the specification type is UPDATED_RACK or EXISTING_RACK.
final_rack_specification_details: Option<RackSpecificationDetails>The final rack specification details after the quote is fulfilled.
server_specification_details: Option<ServerSpecificationDetails>The server specification details, if the specification type is SERVER.
Implementations
Sourceimpl QuoteSpecification
impl QuoteSpecification
Sourcepub fn quote_specification_type(&self) -> Option<&QuoteSpecificationType>
pub fn quote_specification_type(&self) -> Option<&QuoteSpecificationType>
The type of specification. Valid values are NEW_RACK, UPDATED_RACK, EXISTING_RACK, and SERVER.
Sourcepub fn existing_rack_specification_details(
&self,
) -> Option<&RackSpecificationDetails>
pub fn existing_rack_specification_details( &self, ) -> Option<&RackSpecificationDetails>
The existing rack specification details, if the specification type is UPDATED_RACK or EXISTING_RACK.
Sourcepub fn final_rack_specification_details(
&self,
) -> Option<&RackSpecificationDetails>
pub fn final_rack_specification_details( &self, ) -> Option<&RackSpecificationDetails>
The final rack specification details after the quote is fulfilled.
Sourcepub fn server_specification_details(
&self,
) -> Option<&ServerSpecificationDetails>
pub fn server_specification_details( &self, ) -> Option<&ServerSpecificationDetails>
The server specification details, if the specification type is SERVER.
Sourceimpl QuoteSpecification
impl QuoteSpecification
Sourcepub fn builder() -> QuoteSpecificationBuilder
pub fn builder() -> QuoteSpecificationBuilder
Creates a new builder-style object to manufacture QuoteSpecification.